/*
 * [FT.java]
 *
 * Summary: Utility to find out details of file times of a file or directory.
 *
 * Copyright: (c) 2009-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2009-08-25 initial version
 */
package com.mindprod.filetimes;

import java.io.File;

import static java.lang.System.*;

/**
 * Utility to find out details of file times of a file or directory.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2009-08-25 initial version
 * @since 2009-08-25
 */
public class FT
    {
    /**
     * Get time details on a file or directory
     *
     * @param args names of files or dirs you want time details on
     */
    public static void main( String[] args )
        {
        for ( final String arg : args )
            {
            // used Windows conventions in native
            String filename = arg.replace( '/', '\\' );
            final long created = FileTimes.getFileCreated( filename );
            final long modified = FileTimes.getFileLastModified( filename );
            final long accessed = FileTimes.getFileLastAccessed( filename );
            final long msCreated;
            final long msModified;
            final long msAccessed;
            if ( new File( filename ).isDirectory() )
                {
                msCreated = FileTimes.nativeGetDirCreated( filename );
                msModified = FileTimes.nativeGetDirLastModified( filename );
                msAccessed = FileTimes.nativeGetDirLastAccessed( filename );
                }
            else
                {
                msCreated = FileTimes.nativeGetFileCreated( filename );
                msModified = FileTimes.nativeGetFileLastModified( filename );
                msAccessed = FileTimes.nativeGetFileLastAccessed( filename );
                }
            out.println( filename );
            out.println( " created: " + FileTimes.display( created ) + " Java:" + created + " MS:" + msCreated );
            out.println( "modified: " + FileTimes.display( modified ) + " Java:" + modified + " MS:" +
                         msModified );
            out.println( "accessed: " + FileTimes.display( accessed ) + " Java:" + accessed + " MS:" +
                         msAccessed );
            out.println();
            }
        }
    }
